couchdb.schema.TextField

Package couchdb :: Module schema :: Class TextField |

# Class TextField

    object --+
             |
         Field --+
                 |
                TextField

Schema field for string values.

Instance Methods
Inherited from `Field`: `__get__`, `__init__`, `__set__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`